@@ -58,6 +58,9 @@ static inline int assertForbiddenVariables(const char *s) {
 static inline int isReservedVariable(const char *s) {
   return !rxstrcmpi("amt", s) ||
     !rxstrcmpi("time", s) ||
+    !rxstrcmpi("mixnum", s) ||
+    !rxstrcmpi("mixest", s) ||
+    !rxstrcmpi("mixunif", s) ||
     !strcmp("rx__PTR__", s) ||
     !strcmp("tlast", s) ||
     // Ignore M_ constants
@@ -118,6 +121,9 @@ static inline int new_or_ith(const char *s) {
   tb.ix=-2;
   if (tb.fn) {tb.ix=-2; return 0;}
   if (!strcmp("lhs", s)){tb.ix=-1; return 0;}
+  if (strcmp("CMT", s) && !rxstrcmpi("CMT", s)) {
+    return new_or_ith("CMT");
+  }
   if (assertForbiddenVariables(s) == 0) return 0;
   if (skipReservedVariables(s) == 0) return 0;
   // Ignore THETA[] and ETA
